@@ -16,8 +16,9 @@
 #'   or case insensitive searches. Default is `FALSE`.
 #' @param count Default is `FALSE`.
 #' @param drop_corpus When a corpus is specified directly with the ngram 
-#'   (e.g `dog:eng_fiction_2012`) should the corpus be used retained in
-#'   the phrase column of the results. Default is `FALSE`.
+#'   (e.g `dog:eng_fiction_2012`) specifies whether the corpus be used retained in
+#'   the phrase column of the results. Note that that this method requires that
+#'   the old corpus codes (eng_fiction_2012 not en-fiction-2012) are used. Default is `FALSE`.
 #' @param drop_parent  Drop the parent phrase associated with a wildcard
 #'   or case-insensitive search. Default is `FALSE`.
 #' @param drop_all Delete the suffix "(All)" from aggregated case-insensitive
@@ -40,42 +41,43 @@
 #'  Note that the `tag` option is no longer available. Tags should be
 #'  specified directly in the ngram string (see examples).
 #'
-#' Below is a list of available corpora.
+#' Below is a list of available corpora. Note that the data for the 2012
+#' corpuses only extends to 2009.
 #' \tabular{ll}{
 #' \bold{Corpus} \tab \bold{Corpus Name}\cr
-#' eng_us_2019\tab American English 2019\cr
-#' eng_us_2012\tab American English 2012\cr
-#' eng_us_2009\tab American English 2009\cr
-#' eng_gb_2019\tab British English 2019\cr
-#' eng_gb_2012\tab British English 2012\cr
-#' eng_gb_2009\tab British English 2009\cr
-#' chi_sim_2019\tab Chinese 2019\cr
-#' chi_sim_2012\tab Chinese 2012\cr
-#' chi_sim_2009\tab Chinese 2009\cr
-#' eng_2019\tab English 2019\cr
-#' eng_2012\tab English 2012\cr
-#' eng_2009\tab English 2009\cr
-#' eng_fiction_2019\tab English Fiction 2019\cr
-#' eng_fiction_2012\tab English Fiction 2012\cr
-#' eng_fiction_2009\tab English Fiction 2009\cr
-#' eng_1m_2009\tab Google One Million\cr
-#' fre_2019\tab French 2019\cr
-#' fre_2012\tab French 2012\cr
-#' fre_2009\tab French 2009\cr
-#' ger_2019\tab German 2019\cr
-#' ger_2012\tab German 2012\cr
-#' ger_2009\tab German 2009\cr
-#' heb_2019\tab Hebrew 2019\cr
-#' heb_2012\tab Hebrew 2012\cr
-#' heb_2009\tab Hebrew 2009\cr
-#' spa_2019\tab Spanish 2019\cr
-#' spa_2012\tab Spanish 2012\cr
-#' spa_2009\tab Spanish 2009\cr
-#' rus_2019\tab Russian 2019\cr
-#' rus_2012\tab Russian 2012\cr
-#' rus_2009\tab Russian 2009\cr
-#' ita_2019\tab Italian 2019\cr
-#' ita_2012\tab Italian 2012\cr
+#' en-US-2019\tab American English 2019\cr
+#' en-US-2012\tab American English 2012\cr
+#' en-US-2009\tab American English 2009\cr
+#' en-GB-2019\tab British English 2019\cr
+#' en-GB-2012\tab British English 2012\cr
+#' en-GB-2009\tab British English 2009\cr
+#' zh-Hans-2019\tab Chinese 2019\cr
+#' zh-Hans-2012\tab Chinese 2012\cr
+#' zh-Hans-2009\tab Chinese 2009\cr
+#' en-2019\tab English 2019\cr
+#' en-2012\tab English 2012\cr
+#' en-2009\tab English 2009\cr
+#' en-fiction-2019\tab English Fiction 2019\cr
+#' en-fiction-2012\tab English Fiction 2012\cr
+#' en-fiction-2009\tab English Fiction 2009\cr
+#' en-1M-2009\tab English One Million\cr
+#' fr-2019\tab French 2019\cr
+#' fr-2012\tab French 2012\cr
+#' fr-2009\tab French 2009\cr
+#' de-2019\tab German 2019\cr
+#' de-2012\tab German 2012\cr
+#' de-2009\tab German 2009\cr
+#' iw-2019\tab Hebrew 2019\cr
+#' iw-2012\tab Hebrew 2012\cr
+#' iw-2009\tab Hebrew 2009\cr
+#' es-2019\tab Spanish 2019\cr
+#' es-2012\tab Spanish 2012\cr
+#' es-2009\tab Spanish 2009\cr
+#' ru-2019\tab Russian 2019\cr
+#' ru-2012\tab Russian 2012\cr
+#' ru-2009\tab Russian 2009\cr
+#' it-2019\tab Italian 2019\cr
+#' it-2012\tab Italian 2012\cr
 #' }
 #'
 #' The Google Million is a sub-collection of Google Books. All are in
@@ -94,11 +96,10 @@
 #' }
 #' @export
 
-ngram <- function(phrases, corpus = "eng_2019", year_start = 1800, 
+ngram <- function(phrases, corpus = "en-2019", year_start = 1800, 
                       year_end = 2020, smoothing = 3, case_ins=FALSE,
                       aggregate = FALSE, count = FALSE, drop_corpus = FALSE,
                       drop_parent = FALSE, drop_all = FALSE, type = FALSE) {
-  if (class(corpus) == "character")  corpus <- get_corpus_n(corpus, default = "eng_2019")
   phrases <- ngram_check_phrases(phrases)
   # Loop over corpuses
   dfs <- lapply(corpus, function(corp) ngram_single(phrases, corpus = corp,
@@ -136,6 +137,7 @@ ngram <- function(phrases, corpus = "eng_2019", year_start = 1800,
 
 ngram_single <- function(phrases, corpus, year_start, year_end,
                              smoothing, case_ins) {
+  if (!(corpus %in% corpuses$Shorthand)) {warning(paste(corpus, "not a valid corpus. Defaulting to en-2019."))}
   query <- as.list(environment())
   if (case_ins) query["case_insensitive"] <- "on"
   query$phrases <- NULL
@@ -184,30 +186,27 @@ ngram_check_warnings <- function(html) {
 
 ngram_fetch_data <- function(html) {
   corpus <- xml2::xml_find_first(html, "//select[@id='form-corpus']/option")
-  corpus <- as.integer(xml2::xml_attr(corpus, "value"))
-  json <- xml2::xml_find_first(html, "//div[@id='chart']/following::script")
-  json <- xml2::xml_text(json)
+  corpus <- xml2::xml_attr(corpus, "value")
+  script <- xml2::xml_find_all(html, "//div[@id='chart']/following::script")
+  json <- xml2::xml_text(script[1])
   json <- stringr::str_split(json, "\n")[[1]]
   json <- stringr::str_trim(json)
-  years <- as.integer(stringr::str_split(grep("drawD3Chart", json, value = TRUE), ",")[[1]][2:3])
-  json <- grep("ngrams.data =", json, value = TRUE)
-  json <- stringr::str_match(json, "ngrams.data = (.*);")[2]
+  years <- xml2::xml_text(script[2])
+  years <- stringr::str_split(years, "\n")[[1]]
+  years <- as.integer(stringr::str_split(grep("drawD3Chart", years, value = TRUE), ",")[[1]][2:3])
   data <- rjson::fromJSON(json)
   if (length(data) == 0) return(NULL)
   data <- lapply(data,
                  function(x) tibble::add_column(tibble::as_tibble(x),
                                                 Year = seq.int(years[1], years[2])))
   data <- bind_rows(data)
-  data$ngram <- textutils::HTMLdecode(data$ngram)
-  data <- mutate(data, Corpus = get_corpus_text(corpus))
-  data <- separate(data, ngram, c("clean", "C"), ":", remove = FALSE,
-                   extra = "drop", fill = "right")
-  data <- mutate(data, n = get_corpus_n(.data$C),
-                 Corpus = if_else(is.na(n), .data$Corpus, .data$C), C = NULL, n = NULL)
-  data <- dplyr::relocate(data, .data$Year, .data$ngram, .data$timeseries, .data$Corpus)
-  data <- dplyr::rename(data, Phrase = .data$ngram, 
-                        Frequency = .data$timeseries,
-                        Parent = .data$parent)
+  data <- data |> mutate(ngram = textutils::HTMLdecode(data$ngram), Corpus = corpus) |>
+            separate(ngram, c("clean", "C"), ":", remove = FALSE, extra = "drop", fill = "right") |>
+            left_join(select(corpuses, .data$Shorthand, .data$Shorthand.Old), by = c("C" = "Shorthand.Old")) |>
+            mutate(Corpus = if_else(is.na(.data$Shorthand), .data$Corpus, .data$Shorthand)) |> 
+            select(-.data$C, -.data$Shorthand) |>
+            relocate(.data$Year, .data$ngram, .data$timeseries, .data$Corpus) |>
+            rename(Phrase = .data$ngram,  Frequency = .data$timeseries, Parent = .data$parent)
   return(data)
 }
 
@@ -232,20 +231,6 @@ ngram_url <- function(phrases, query=character()) {
   return(url)
 }
 
-get_corpus <- function(corpus, text = TRUE) {
-  corpora <- c("eng_us_2012" = 17, "eng_us_2009" = 5, "eng_gb_2012" = 18,
-               "eng_gb_2009" = 6, "chi_sim_2012" = 23, "chi_sim_2009" = 11,
-               "eng_2012" = 15, "eng_2009" = 0, "eng_fiction_2012" = 16,
-               "eng_fiction_2009" = 4, "eng_1m_2009" = 1, "fre_2012" = 19,
-               "fre_2009" = 7, "ger_2012" = 20, "ger_2009" = 8, "heb_2012" = 24,
-               "heb_2009" = 9, "spa_2012" = 21, "spa_2009" = 10, "rus_2012" = 25,
-               "rus_2009" = 12, "ita_2012" = 22, "eng_2019" = 26,
-               "eng_us_2019" = 28, "eng_gb_2019" = 29, "eng_fiction_2019" = 27,
-               "chi_sim_2019" = 34, "fre_2019" = 30, "ger_2019" = 31, "heb_2019" = 35,
-               "ita_2019" = 33, "rus_2019" = 36, "spa_2019" = 32)
-  if (text) return(unname(corpora[corpus])) else return(names(which(corpora  == corpus)))
-}
-
 check_balanced <- function(x) {
   # Check parenthesis are appropriately balanced (i.e. every open is closed)
   sapply(x, function(str) {
@@ -292,6 +277,7 @@ get_corpus_text <- function(n, default = NA){
 
 truncate_years <- function(ngram){
   stopifnot(class(ngram)[1] == "ngram")
+  ngram$Corpus <- as.character(ngram$Corpus)
   ngram <- left_join(ngram, select(corpuses,
                                    .data$Shorthand,
                                    .data$Last.Year),
